summaryrefslogtreecommitdiff
path: root/package/cfgfs
diff options
context:
space:
mode:
authorWaldemar Brodkorb <wbx@openadk.org>2011-07-28 17:08:33 +0200
committerWaldemar Brodkorb <wbx@openadk.org>2011-07-28 17:08:33 +0200
commit03db81babfc6ba4f21ceb26aa15fd0a208075b92 (patch)
tree05290c1c2de4a6cdfc731c9f98e99afdea123cf9 /package/cfgfs
parentf22fcb9264ec8141c412fae5cf4c320a5eba3d10 (diff)
search as fallback on /dev/sda for cfgfs partition
Diffstat (limited to 'package/cfgfs')
-rw-r--r--package/cfgfs/Makefile2
-rw-r--r--package/cfgfs/src/fwcf.sh10
2 files changed, 8 insertions, 4 deletions
diff --git a/package/cfgfs/Makefile b/package/cfgfs/Makefile
index bec5fe6e6..6fa32318e 100644
--- a/package/cfgfs/Makefile
+++ b/package/cfgfs/Makefile
@@ -5,7 +5,7 @@ include ${TOPDIR}/rules.mk
PKG_NAME:= cfgfs
PKG_VERSION:= 1.0.8
-PKG_RELEASE:= 6
+PKG_RELEASE:= 7
PKG_DESCR:= compressed config filesystem
PKG_SECTION:= base
PKG_URL:= http://openadk.org/
diff --git a/package/cfgfs/src/fwcf.sh b/package/cfgfs/src/fwcf.sh
index b37da0bcd..0fac5ec1f 100644
--- a/package/cfgfs/src/fwcf.sh
+++ b/package/cfgfs/src/fwcf.sh
@@ -130,9 +130,13 @@ rootdisk=${rootdisk%p*}
rootdisk=${rootdisk%[1-9]}
part=$(fdisk -l /dev/$rootdisk 2>/dev/null|awk '$5 == 88 { print $1 }')
if [ -z $part ]; then
- # otherwise search for MTD device with name cfgfs
- part=/dev/mtd$(fgrep '"cfgfs"' /proc/mtd 2>/dev/null | sed 's/^mtd\([^:]*\):.*$/\1/')ro
- mtd=1
+ # fallback to /dev/sda in case of encrypted root
+ part=$(fdisk -l /dev/sda 2>/dev/null|awk '$5 == 88 { print $1 }')
+ if [ -z $part ]; then
+ # otherwise search for MTD device with name cfgfs
+ part=/dev/mtd$(fgrep '"cfgfs"' /proc/mtd 2>/dev/null | sed 's/^mtd\([^:]*\):.*$/\1/')ro
+ mtd=1
+ fi
fi
if [[ ! -e $part ]]; then